require 'json'
require 'script_executor/executable'
require 'script_executor/script_locator'
require 'text_interpolator'

class OracleClientInstaller
  include Executable, ScriptLocator

  attr_reader :env, :script_list, :interpolator

  def initialize config_file_name
    @interpolator = TextInterpolator.new

    @env = read_config(config_file_name)

    puts "ruby home: #{env[:ruby_home]}"
    puts "ruby_oci_version: #{env[:ruby_oci_version]}"
    puts "user: #{env[:user]}"

    @script_list = scripts(File.expand_path('scripts.sh', File.dirname(__FILE__)))
  end

  def install
    run({:sudo => true, :capture_output => true}, "install", env)

    run({}, "install-ruby-oci8", env)
  end

  def uninstall
    run({:sudo => true}, "uninstall", env)
  end

  def verify &code
    run({}, "verify", env.merge(:cmd => code.call))
  end

  private

  def read_config config_file_name
    hash = JSON.parse(File.read(config_file_name), :symbolize_names => true)

    interpolator.interpolate hash
  end

  def run server_info, script_name, env
    execute(server_info) { evaluate_script_body(script_list[script_name], env, :string) }
  end

end
